#!/bin/sh
# the next line restarts using tclsh \
exec tclsh "$0" ${1+"$@"}

#
# This is a Tcl script to format nmr robot data 
#
# fid directories have directory names similar to: xxx_01, xxx_02, xxx_96 ...
# where xxx can be any string of characters.
#
# input is the directory file structure used in the robot nmr software.
# output is a summary table (text file) and a directory of the fids in 
# an output directory currently named 'all_fids'.
#

##################################################################################

# globals
set PROG			"robotnmr"
set VERSION         "0.85"
set VERSION_DATE    "Mar 2008"


# check arguments
if { $argc <  1 } {
	puts "Usage: $PROG data_directory_name"
	exit
}
if { $argc >  1 } {
	puts "Usage: $PROG data_directory_name"
	exit
}

# get file names 
set datadir $argv 
set fiddir $argv/all_fids 

# start with empty output directory
set cmd "rm -rf $fiddir"
eval exec $cmd
set cmd "mkdir $fiddir"
if [catch {eval exec $cmd } err] {
	puts "Error: Not able to create output directory"
}

# analyze results
set files [glob $datadir/*]
foreach i $files {
	if { [file isdirectory $i/info] } {
		if [catch { set finp [open $i/barcode r]} in] {
			set barcode "--------"
		} else {
			gets $finp barcode
		}

		set success 1
		set fn [file tail $i]
		set num [lindex [split $fn _] end]
		set nd [scan $num "%d" iNum]

		# see if the experiment ran successfully
		if [catch {set fid [glob $i/data/*.fid]} err] {
			set success 0
			set timesaved "--------"
			set cmd "touch $fiddir/sample$iNum.fid"
			if [catch {eval exec $cmd } err] {
				puts "Error: Not able to create file $fiddir/sample$iNum.fid"
			}
		} else {
			set lastfid [lindex [lsort -decreasing $fid] 0]
			set fidfile [file tail $lastfid]
			set tsave [lindex [split $fidfile T_] 1]
			set hh [string range $tsave 0 1]
			set mm [string range $tsave 2 3]
			set ss [string range $tsave 4 5]
			set timesaved "$hh:$mm:$ss" 

			# put a copy of the input fid dir into the all_fids directory
			set cmd "cp -pr $lastfid $fiddir/sample$iNum.fid"
			if [catch {eval exec $cmd } err] {
				puts "Error: Not able to copy $lastfid to $fiddir"
			}

		}
		puts stdout "$fn $timesaved $barcode $success"
	}
} 
